@@ -24,6 +24,7 @@
 #'@param giLinks        list. of GI tools cli paths
 #'@param majorityRadius numeric. kernel size for the majority filter out spurious pixel
 #'@param parallel running parallel or not default = 1
+#' @return sp* object
 #'@export
 #'@examples
 #' \dontrun{
@@ -32,7 +33,7 @@
 #' require(link2GI)
 #' ##- linkages
 #' ##- create and check the links to the GI software
-#' giLinks<-uavRst::linkAll(linkItems = c("saga","gdal"))
+#' giLinks<-uavRst::linkGI(linkItems = c("saga","gdal"))
 #' if (giLinks$saga$exist ) {
 #'
 #' ##- project folder
@@ -98,11 +99,11 @@ chmseg_GWS <- function(treepos = NULL,
   }
 
 
-  cat("::: run main segmentation...\n")
+  message("::: run main segmentation...\n")
   # create correct param lists
   #segmentationBands<-c("HI","GLI")
   if (is.null(giLinks)){
-    giLinks <- linkAll()
+    giLinks <- linkGI()
   }
 
   gdal <- giLinks$gdal
@@ -149,7 +150,7 @@ chmseg_GWS <- function(treepos = NULL,
     else {
       file.copy(file.path(R.utils::getAbsolutePath(path_run),"/crowns.sgrd"),file.path(R.utils::getAbsolutePath(path_run),"/crowns1.sgrd"),overwrite = TRUE)
       file.copy(file.path(R.utils::getAbsolutePath(path_run),"/crowns.sdat"),file.path(R.utils::getAbsolutePath(path_run),"/crowns1.sdat"),overwrite = TRUE)
-      cat(getCrayon()[[2]]("\n GDAL Python module 'sieve' is NOT found. Expected to be at: "),
+      message(getCrayon()[[2]]("\n GDAL Python module 'sieve' is NOT found. Expected to be at: "),
           getCrayon()[[4]](names(gdal$python_utilities),"\n" ))
       }
     # apply majority filter for smoothing the extremly irregular crown boundaries
@@ -198,7 +199,7 @@ chmseg_GWS <- function(treepos = NULL,
     # crowns <- rgdal::readOGR(dsn = file.path(R.utils::getAbsolutePath(path_run)),
     #                        layer = "crowns", 
     #                        verbose = FALSE)
-  else return(cat(paste0("File ",file.path(R.utils::getAbsolutePath(path_run)),"/crowns.shp not found \n")))
+  else return(message(paste0("File ",file.path(R.utils::getAbsolutePath(path_run)),"/crowns.shp not found \n")))
   
   #crowns<-tree_crowns[tree_crowns$VALUE > 0,]
   sp::proj4string(crowns)<-proj
@@ -220,7 +221,7 @@ chmseg_GWS <- function(treepos = NULL,
                     driver= "ESRI Shapefile",
                     overwrite=TRUE)
   }
-  else return(cat(paste0("File ",file.path(R.utils::getAbsolutePath(path_run)),"spdf.shp not found \n")))
+  else return(message(paste0("File ",file.path(R.utils::getAbsolutePath(path_run)),"spdf.shp not found \n")))
   
 
   # simple filtering of crownareas based on tree height min max area and artifacts at the analysis/image borderline
@@ -232,7 +233,7 @@ chmseg_GWS <- function(treepos = NULL,
   
   #nrow(tree_crowns[[1]])
   options(warn=0)
-  cat("segmentation finsihed...\n")
+  message("segmentation finsihed...\n")
   sp::proj4string(statRawCrowns)<-sp::proj4string(tree_crowns[[1]])
   tree_crowns<- append(tree_crowns,statRawCrowns)
   return(tree_crowns)
@@ -253,7 +254,7 @@ chmseg_GWS <- function(treepos = NULL,
 #' @param format character. Format of the function's output. Can be set to either 'raster' or 'polygons'.
 #' @param winRadius numeric the fixed radius written in the SPDF of the tree top file if not generated by Foresttools
 #' @param verbose to be quiet FALSE
-#'
+#' @return sp* object
 #' @export
 #' 
 #' @examples
@@ -328,7 +329,7 @@ chmseg_FT <- function(treepos = NULL,
 #' @param maxCrownArea numeric. A single value of the minimum projected tree crown area allowed. Default is 100 sqm
 #' height of \code{treepos}.
 #' @param exclusion numeric. A single value from 0 to 1 that represents the percent of pixel exclusion.
-
+#' @return sp* object
 #' @export
 #' @examples
 
@@ -406,7 +407,7 @@ chmseg_RL <- function(treepos = NULL,
 #' @param minTreeAlt numeric. Height threshold (m) below a pixel cannot be a local maximum. Local maxima values are used to define tree tops.\href{https://CRAN.R-project.org/package=itcSegment}{itcSegment}
 #' @param TRESHSeed numeric. seeding threshold. \href{https://CRAN.R-project.org/package=itcSegment}{itcSegment}
 #' @param TRESHCrown numeric. crowns threshold. \href{https://CRAN.R-project.org/package=itcSegment}{itcSegment}
-
+#' @return sp* object
 #' @export chmseg_ITC
 #' @examples
 
